Missing Use Cases
=================

  "ContentCreator":Actor_ContentCreator

   - "Define content metadata":ChangeMetadata

   - "Make a content object discussable":EnableDiscussion

  "MembershipManager":Actor_MembershipManager

   - "Add a new member to the site using a standard user
      folder":AddMemberToUserFolder

   - "Change member information and abilities":ChangeMemberInformation

   - "Browse member roster":BrowseMemberRoster

   - "Remove a member from the site":RemoveMemberFromSite

  "SiteDesigner":Actor_SiteDesigner

   - "Create new skin for the site":CreateNewSkin

   - "Modify skin appearance":ChangeSkinLookAndFeel

   - "Change skin behavior":ChangeSkinBehavior

   - "Change the default skin for the site":ChangeDefaultSiteSkin

  "SiteManager":Actor_SiteManager

   - "Configure CMF Topic":ConfigureCMFTopic

   - "Configure what types of content can be created
      by users":ConfigureAllowedContentTypes

   - "Configure security for a content object
      or folder":ConfigureObjectSecurity

   - "Associate a workflow with a content
      type":AssociateWorkflowWithContentType

   - "Configure required metadata for a content
      type":ConfigureRequiredMetadata

   - "Configure what content is released via
      syndication":ConfigureContentSyndiation

  "SiteVisitor":Actor_SiteVisitor

   - "Submit a news item":SubmitNewsItem

   - "Browse a portal topic":BrowsePortalTopic

